############################ -*- Mode: Makefile -*- ###########################
## targets.mk ---
## Author           : Manoj Srivastava ( srivasta@glaurung.green-gryphon.com )
## Created On       : Sat Nov 15 01:10:05 2003
## Created On Node  : glaurung.green-gryphon.com
## Last Modified By : Manoj Srivastava
## Last Modified On : Tue Oct  9 01:50:58 2007
## Last Machine Used: anzu.internal.golden-gryphon.com
## Update Count     : 95
## Status           : Unknown, Use with caution!
## HISTORY          :
## Description      : The top level targets mandated by policy, as well as
##                    their dependencies.
##
## arch-tag: a81086a7-00f7-4355-ac56-8f38396935f4
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##
###############################################################################

#######################################################################
#######################################################################
###############             Miscellaneous               ###############
#######################################################################
#######################################################################
source diff:
	@echo >&2 'source and diff are obsolete - use dpkg-source -b'; false

define TESTROOT
	@test $$(id -u) = 0 || (echo need root priviledges; exit 1)
endef

testroot:
	$(TESTROOT)

checkpo:
	$(CHECKPO)

# arch-buildpackage likes to call this
prebuild:

# OK. We have two sets of rules here, one for arch dependent packages,
# and one for arch independent packages. We have already calculated a
# list of each of these packages.

# In each set, we may need to do things in five steps: configure,
# build, install, package, and clean. Now, there can be a common
# actions to be taken for all the packages, all arch dependent
# packages, all all independent packages, and each package
# individually at each stage.

###########################################################################
# The current code does a number of things: It ensures that the highest   #
# dependency at any stage (usually the -Common target) depends on the	  #
# stamp-STAGE of the previous stage; so no work on a succeeding stage can #
# start before the previous stage is all done.				  #
###########################################################################


#######################################################################
#######################################################################
###############             Configuration               ###############
#######################################################################
#######################################################################
# Just a dummy target to make sure that the stamp directory exists
debian/stamp/config-common:
	$(REASON)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

# Configuration tasks common to arch and arch indep packages go here
debian/stamp/CONFIG-common:: debian/stamp/config-common
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

# Arch specific and arch independent tasks go here
debian/stamp/CONFIG-arch::  debian/stamp/CONFIG-common
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@
debian/stamp/CONFIG-indep:: debian/stamp/CONFIG-common
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

# Per package configuration happens here
$(patsubst %,debian/stamp/CONFIG/%,$(DEB_ARCH_PACKAGES))  :: debian/stamp/CONFIG/% : debian/stamp/CONFIG-arch
	$(REASON)
	$(checkdir)
	@test -d debian/stamp/CONFIG || mkdir -p debian/stamp/CONFIG
	@echo done > $@
$(patsubst %,debian/stamp/CONFIG/%,$(DEB_INDEP_PACKAGES)) :: debian/stamp/CONFIG/% : debian/stamp/CONFIG-indep
	$(REASON)
	$(checkdir)
	@test -d debian/stamp/CONFIG || mkdir debian/stamp/CONFIG
	@echo done > $@

debian/stamp/configure-arch: $(patsubst %,debian/stamp/CONFIG/%,$(DEB_ARCH_PACKAGES))
	$(REASON)
	@test -d debian/stamp/CONFIG || mkdir debian/stamp/CONFIG
	@echo done > $@
debian/stamp/configure-indep: $(patsubst %,debian/stamp/CONFIG/%,$(DEB_INDEP_PACKAGES))
	$(REASON)
	@test -d debian/stamp/CONFIG || mkdir debian/stamp/CONFIG
	@echo done > $@

# These three targets are required by policy
configure-arch:  debian/stamp/configure-arch
	$(REASON)
configure-indep: debian/stamp/configure-indep
	$(REASON)
configure: debian/stamp/configure-arch debian/stamp/configure-indep
	$(REASON)

#######################################################################
#######################################################################
###############                 Build                   ###############
#######################################################################
#######################################################################
# tasks common to arch and arch indep packages go here
debian/stamp/BUILD-common:: 
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

# Arch specific and arch independent tasks go here
debian/stamp/BUILD-arch::  debian/stamp/configure-arch
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@test -e debian/stamp/BUILD-common || $(MAKE) -f debian/rules debian/stamp/BUILD-common
	@echo done > $@

debian/stamp/BUILD-indep:: debian/stamp/configure-indep
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@test -e debian/stamp/BUILD-common || $(MAKE) -f debian/rules debian/stamp/BUILD-common
	@echo done > $@

# Per package work happens here
$(patsubst %,debian/stamp/BUILD/%,$(DEB_ARCH_PACKAGES))  :: debian/stamp/BUILD/% : debian/stamp/BUILD-arch
	$(REASON)
	$(checkdir)
	@test -d debian/stamp/BUILD || mkdir -p debian/stamp/BUILD
	@echo done > $@

$(patsubst %,debian/stamp/BUILD/%,$(DEB_INDEP_PACKAGES)) :: debian/stamp/BUILD/% : debian/stamp/BUILD-indep
	$(REASON)
	$(checkdir)
	@test -d debian/stamp/BUILD || mkdir -p debian/stamp/BUILD
	@echo done > $@


debian/stamp/build-arch: $(patsubst %,debian/stamp/BUILD/%,$(DEB_ARCH_PACKAGES)) 
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir -p debian/stamp
	@echo done > $@
debian/stamp/build-indep: $(patsubst %,debian/stamp/BUILD/%,$(DEB_INDEP_PACKAGES))
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir -p debian/stamp
	@echo done > $@

# required
build-arch: debian/stamp/build-arch
	$(REASON)
build-indep: debian/stamp/build-indep
	$(REASON)
build: debian/stamp/build-arch debian/stamp/build-indep
	$(REASON)

# Work here
debian/stamp/POST-BUILD-arch-stamp:: debian/stamp/build-arch
	$(REASON)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

debian/stamp/POST-BUILD-indep-stamp:: debian/stamp/build-indep
	$(REASON)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

#######################################################################
#######################################################################
###############                Install                  ###############
#######################################################################
#######################################################################
# tasks common to arch and arch indep packages go here
debian/stamp/INST-common::
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

# Arch specific and arch independent tasks go here
debian/stamp/INST-arch::  debian/stamp/build-arch
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@test -e debian/stamp/INST-common || $(MAKE) -f debian/rules debian/stamp/INST-common
	@echo done > $@

debian/stamp/INST-indep:: debian/stamp/build-indep
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@test -e debian/stamp/INST-common || $(MAKE) -f debian/rules debian/stamp/INST-common
	@echo done > $@


#Per package work happens here
$(patsubst %,debian/stamp/INST/%,$(DEB_ARCH_PACKAGES))  :: debian/stamp/INST/% : debian/stamp/INST-arch
	$(REASON)
	$(checkdir)
	@test -d debian/stamp/INST || mkdir debian/stamp/INST
	@echo done > $@
$(patsubst %,debian/stamp/INST/%,$(DEB_INDEP_PACKAGES)) :: debian/stamp/INST/% : debian/stamp/INST-indep
	$(REASON)
	$(checkdir)
	@test -d debian/stamp/INST || mkdir debian/stamp/INST
	@echo done > $@


debian/stamp/install-arch:$(patsubst %,debian/stamp/INST/%,$(DEB_ARCH_PACKAGES))
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@
debian/stamp/install-indep: $(patsubst %,debian/stamp/INST/%,$(DEB_INDEP_PACKAGES))
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

#required
install-arch:  debian/stamp/install-arch
	$(REASON)
	$(TESTROOT)
install-indep: debian/stamp/install-indep
	$(REASON)
	$(TESTROOT)
install: debian/stamp/install-arch debian/stamp/install-indep
	$(REASON)
	$(TESTROOT)

#######################################################################
#######################################################################
###############                Package                  ###############
#######################################################################
#######################################################################
# tasks common to arch and arch indep packages go here
debian/stamp/BIN-common::
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@

# Arch specific and arch independent tasks go here
debian/stamp/BIN-arch::  debian/stamp/install-arch
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@test -e debian/stamp/BIN-common || $(MAKE) -f debian/rules debian/stamp/BIN-common
	@echo done > $@

debian/stamp/BIN-indep:: debian/stamp/install-indep
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@test -e debian/stamp/BIN-common || $(MAKE) -f debian/rules debian/stamp/BIN-common
	@echo done > $@

# Per package work happens here
$(patsubst %,debian/stamp/BIN/%,$(DEB_ARCH_PACKAGES))  :: debian/stamp/BIN/% : debian/stamp/BIN-arch
	$(REASON)
	$(checkdir)
	@test -d debian/stamp/BIN || mkdir debian/stamp/BIN
	@echo done > $@

$(patsubst %,debian/stamp/BIN/%,$(DEB_INDEP_PACKAGES)) :: debian/stamp/BIN/% : debian/stamp/BIN-indep
	$(REASON)
	$(checkdir)
	@test -d debian/stamp/BIN || mkdir debian/stamp/BIN
	@echo done > $@

debian/stamp/binary-arch:  $(patsubst %,debian/stamp/BIN/%,$(DEB_ARCH_PACKAGES))
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@
debian/stamp/binary-indep: $(patsubst %,debian/stamp/BIN/%,$(DEB_INDEP_PACKAGES))
	$(REASON)
	$(checkdir)
	@test -d debian/stamp || mkdir debian/stamp
	@echo done > $@
# required
binary-arch:  debian/stamp/binary-arch
	$(REASON)
	$(TESTROOT)
binary-indep: debian/stamp/binary-indep
	$(REASON)
	$(TESTROOT)
binary: debian/stamp/binary-arch debian/stamp/binary-indep
	$(REASON)
	$(TESTROOT)
	@echo arch package   = $(DEB_ARCH_PACKAGES)
	@echo indep packages = $(DEB_INDEP_PACKAGES)

#######################################################################
#######################################################################
###############                 Clean                   ###############
#######################################################################
#######################################################################
# Work here
CLN-common:: 
	$(REASON)
	$(checkdir)

# sync Work here
CLN-arch::  CLN-common
	$(REASON)
	$(checkdir)
CLN-indep:: CLN-common
	$(REASON)
	$(checkdir)
# Work here
$(patsubst %,CLEAN/%,$(DEB_ARCH_PACKAGES))  :: CLEAN/% : CLN-arch
	$(REASON)
	$(checkdir)
$(patsubst %,CLEAN/%,$(DEB_INDEP_PACKAGES)) :: CLEAN/% : CLN-indep
	$(REASON)
	$(checkdir)

clean-arch: CLN-arch $(patsubst %,CLEAN/%,$(DEB_ARCH_PACKAGES))
	$(REASON)
clean-indep: CLN-indep $(patsubst %,CLEAN/%,$(DEB_INDEP_PACKAGES))
	$(REASON)
clean: clean-indep clean-arch
	$(REASON)
	-test -f Makefile && $(MAKE) distclean
	-rm -f  $(FILES_TO_CLEAN) $(STAMPS_TO_CLEAN)
	-rm -rf $(DIRS_TO_CLEAN) debian/stamp
	-rm -f core TAGS                                                     \
	       `find . ! -regex '.*/\.git/.*' ! -regex '.*/\{arch\}/.*'      \
	       	       ! -regex '.*/CVS/.*'   ! -regex '.*/\.arch-ids/.*'    \
	               ! -regex '.*/\.svn/.*'                                \
	       	   \( -name '*.orig' -o -name '*.rej' -o -name '*~'       -o \
	              -name '*.bak'  -o -name '#*#'   -o -name '.*.orig'  -o \
	       	      -name '.*.rej' -o -name '.SUMS' \)                     \
	        -print`


#######################################################################
#######################################################################
###############                                         ###############
#######################################################################
#######################################################################
.PHONY: configure-arch  configure-indep  configure     \
        build-arch      build-indep      build         \
        install-arch    install-indep    install       \
        binary-arch     binary-indep     binary        \
        CLN-common     CLN-indep     CLN-arch     clean-arch      clean-indep      clean         \
        $(patsubst %,CLEAN/%, $(DEB_INDEP_PACKAGES)) $(patsubst %,CLEAN/%, $(DEB_ARCH_PACKAGES)) \
        implode explode prebuild checkpo


#Local variables:
#mode: makefile
#End:
